import React, { CSSProperties, HTMLAttributes } from "react";
import { ProgressProps } from "./types";
export interface LinearProgressProps extends Omit<HTMLAttributes<HTMLDivElement>, "id">, ProgressProps {
    /**
     * An optional style to apply to the progress bar. This will be merged with
     * the current width or height tracking the progress when a `value` is also
     * provided.
     */
    barStyle?: CSSProperties;
    /**
     * An optional className to apply to the progress bar.
     */
    barClassName?: string;
    /**
     * Boolean if the progress should be reversed. This will change the progress
     * direction from `left-to-right` to be `right-to-left`. If the current
     * language is a rtl language and this prop is enabled, the direction will
     * still be `left-to-right`.
     */
    reverse?: boolean;
    /**
     * Boolean if the progress should be vertical instead of horizontal.  When
     * this prop is set, you should also set the `verticalHeight` prop to a height
     * value you want for your progress bar.
     */
    vertical?: boolean;
    /**
     * Since there isn't really a good way to have "auto height", you'll need to
     * manually set the progress bar's height with this prop to some pixel value.
     * If you'd prefer to set the height in Sass/css, set this value to `null`
     * instead since this value would be passed down as a `height` inline style.
     */
    verticalHeight?: number | null;
}
declare const LinearProgress: React.ForwardRefExoticComponent<LinearProgressProps & React.RefAttributes<HTMLSpanElement>>;
export default LinearProgress;
